@@ -1,42 +1,43 @@
 #' Create species' values based on the species co-occurrence within focal ranges
-#' 
-#' @author Bruno Vilela & Fabricio Villalobos
-#' 
-#' @description Create single species' values based on the attributes of species 
-#' co-occurring within individual ranges.
-#' 
-#' @param x A \code{\link{PresenceAbsence}} object or a presence-absence in \code{matrix}
-#' format (see xy argument for matrix use) with the species named in the columns.
-#' @param y Species attribute to be considered. It must be a numeric attribute.
-#' @param z Species names in the same order as the attributes and exactly the 
-#' same as named in the \code{matrix} or in the \code{PresenceAbsence} object.
-#' @param weight If \code{TRUE} the value is weighted by species' range size, 
-#' if \code{FALSE} the value is the mean of all species that co-occur within the
-#'  focal species.
-#' @param xy If \code{TRUE} the presence-absence \code{matrix} contains 
-#' the cell coordinates in the first two columns.
-#' @param count Logical, if \code{TRUE} a counting window will open.
-#'  
-#' @details If the species do not co-occur with any other species NaN will be 
-#' returned. 
 #'
-#' @references Villalobos, F. and Arita, H.T. 2010. The diversity field of 
-#' New World leaf-nosed bats (Phyllostomidae). Global Ecology and Biogeography. 
-#' 19, 200-211. 
-#' @references Villalobos, F., Rangel, T.F., and Diniz-Filho, J.A.F. 2013. 
-#' Phylogenetic fields of species: cross-species patterns of phylogenetic 
-#' structure and geographical coexistence. Proceedings of the Royal 
-#' Society B. 280, 20122570.
-#' 
+#' @author Bruno Vilela & Fabricio Villalobos
+#'
+#' @description Create single species' values based on the attributes of species
+#'   co-occurring within individual ranges.
+#'
+#' @param x A \code{\link{PresenceAbsence}} object or a presence-absence in
+#'   \code{matrix} format (see xy argument for matrix use) with the species
+#'   named in the columns.
+#' @param y Species attribute to be considered. It must be a numeric attribute.
+#' @param z Species names in the same order as the attributes and exactly the
+#'   same as named in the \code{matrix} or in the \code{PresenceAbsence} object.
+#' @param weight If \code{TRUE} the value is weighted by species' range size, if
+#'   \code{FALSE} the value is the mean of all species that co-occur within the
+#'   focal species.
+#' @param xy If \code{TRUE} the presence-absence \code{matrix} contains the cell
+#'   coordinates in the first two columns.
+#' @param count Logical, if \code{TRUE} a counting window will open.
+#'
+#' @details If the species do not co-occur with any other species NaN will be
+#'   returned.
+#'
+#' @references Villalobos, F. and Arita, H.T. 2010. The diversity field of New
+#'   World leaf-nosed bats (Phyllostomidae). Global Ecology and Biogeography.
+#'   19, 200-211.
+#' @references Villalobos, F., Rangel, T.F., and Diniz-Filho, J.A.F. 2013.
+#'   Phylogenetic fields of species: cross-species patterns of phylogenetic
+#'   structure and geographical coexistence. Proceedings of the Royal Society B.
+#'   280, 20122570.
+#'
 #' @seealso \code{\link{lets.presab.birds}}
 #' @seealso \code{\link{lets.presab}}
-#' 
+#'
 #' @examples \dontrun{
 #' data(PAM)
 #' range <- lets.rangesize(x = PAM, units = "cell")
 #' field <- lets.field(PAM, range, PAM$S, weight = TRUE)
 #' }
-#' 
+#'
 #' @export
 
 
@@ -44,7 +45,8 @@ lets.field <- function(x, y, z, weight = TRUE,
                        xy = NULL, count = FALSE) {
   
   # Get the matrix without the coordinates
-  if (class(x)[1] == "PresenceAbsence") {
+  if (inherits(x, "PresenceAbsence")) {
+    x <- .check_pam(x)
     p <- x[[1]][, -(1:2)]
     namesSpe <- x[[3]]
   } 
@@ -88,15 +90,15 @@ lets.field <- function(x, y, z, weight = TRUE,
   # With count 
   if (count) {
     if (!"tools:rstudio" %in% search()) {
-      dev.new(width = 2, height = 2, pointsize = 12)
-      par(mar = c(0, 0, 0, 0))
+      grDevices::dev.new(width = 2, height = 2, pointsize = 12)
+      graphics::par(mar = c(0, 0, 0, 0))
     }
     for(i in 1:n){
-      plot.new()
+      graphics::plot.new()
       text(0.5, 0.5, paste(paste("Total:", n, "\n", "Runs to go: ", (n - i))))
       media[i] <- .InsiLoop(i, p, p2, weight)
     }
-    dev.off()
+    grDevices::dev.off()
   }
   
   # Without count
