@@ -1,13 +1,18 @@
 context("Test for lets.presab.grid")
 
-# Grid
-sp.r <- rasterToPolygons(raster(resol = 5))
-slot(sp.r, "data") <- cbind("ID" = 1:length(sp.r),
-                            slot(sp.r, "data"))
-
 # Species polygons
 data(Phyllomedusa)
-projection(Phyllomedusa) <- projection(sp.r)
+
+# Grid
+sp.r <- terra::as.polygons(terra::rast(
+  resol = 5,
+  crs = terra::crs(Phyllomedusa),
+  xmin = -93,
+  xmax = -29,
+  ymin = -57,
+  ymax = 15
+))
+sp.r$ID <- 1:length(sp.r)
 
 
 test_that("lets.presab.grid works fine", {
