@@ -9,7 +9,7 @@ test_that("lets.subsetPAM works fine, remove.cells = TRUE", {
   
   expect_equal(class(resu_test)[1], "PresenceAbsence")
   expect_equal(class(resu_test[[1]])[1], "matrix")
-  expect_true(inherits(resu_test[[2]], "RasterLayer"))
+  expect_true(inherits(resu_test[[2]], "SpatRaster"))
   expect_equal(class(resu_test[[3]])[1], "character")
   
   response <- summary(resu_test)
@@ -25,7 +25,7 @@ test_that("lets.subsetPAM works fine, remove.cells = FALSE", {
   
   expect_equal(class(resu_test)[1], "PresenceAbsence")
   expect_equal(class(resu_test[[1]])[1], "matrix")
-  expect_true(inherits(resu_test[[2]], "RasterLayer"))
+  expect_true(inherits(resu_test[[2]], "SpatRaster"))
   expect_equal(class(resu_test[[3]])[1], "character")
   
   response <- summary(resu_test)
